@@ -26,7 +26,6 @@
 #include "gcal-utils.h"
 
 #include <glib/gi18n.h>
-#include <handy.h>
 
 struct _GcalEventPopover
 {
@@ -380,10 +379,17 @@ update_date_time_label (GcalEventPopover *self)
       g_autofree gchar *start_str = NULL;
       g_autofree gchar *end_str = NULL;
       gboolean show_year;
+      g_autoptr (GDateTime) real_end_dt = NULL;
 
       show_year = g_date_time_get_year (start_dt) != g_date_time_get_year (end_dt);
       start_str = format_multiday_date (self, start_dt, show_year, show_hours);
-      end_str = format_multiday_date (self, end_dt, show_year, show_hours);
+
+      if (!show_hours)
+        real_end_dt = g_date_time_add_days (end_dt, -1);
+      else
+        real_end_dt = g_date_time_ref (end_dt);
+      
+      end_str = format_multiday_date (self, real_end_dt, show_year, show_hours);
 
       /* Translators: %1$s is the start date, and %2$s. For example: June 21 - November 29, 2022 */
       g_string_printf (string, _("%1$s — %2$s"), start_str, end_str);
@@ -416,7 +422,7 @@ add_meeting (GcalEventPopover *self,
 
   row = gcal_meeting_row_new (url);
   g_signal_connect (row, "join-meeting", G_CALLBACK (on_join_meeting_cb), self);
-  gtk_container_add (GTK_CONTAINER (self->meetings_listbox), row);
+  gtk_list_box_append (self->meetings_listbox, row);
 
   gtk_widget_show (GTK_WIDGET (self->meetings_listbox));
 }
@@ -510,18 +516,12 @@ on_join_meeting_cb (GcalMeetingRow   *meeting_row,
                     const gchar      *url,
                     GcalEventPopover *self)
 {
-  g_autoptr (GError) error = NULL;
   GtkWindow *window;
 
-  window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self)));
+  window = GTK_WINDOW (gtk_widget_get_native (GTK_WIDGET (self)));
   g_assert (window != NULL);
 
-  gtk_show_uri_on_window (window, url, GDK_CURRENT_TIME, &error);
-  if (error)
-    {
-      g_warning ("Error opening URL: %s", error->message);
-      return;
-    }
+  gtk_show_uri (window, url, GDK_CURRENT_TIME);
 
   /* For some reason, gtk_popover_popdown() crashes when called here */
   gtk_widget_hide (GTK_WIDGET (self));
