@@ -43,18 +43,24 @@ G_DEFINE_AUTOPTR_CLEANUP_FUNC (ECalComponent, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GWeatherLocation, gweather_location_unref)
 #endif
 
+typedef void (*GcalAskRecurrenceCallback) (GcalEvent             *event,
+                                           GcalRecurrenceModType  modtype,
+                                           gpointer               user_data);
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (ICalTime, g_object_unref)
 
 gchar*               gcal_get_weekday                            (gint                i);
 
 gchar*               gcal_get_month_name                         (gint                i);
 
-cairo_surface_t*     gcal_get_surface_from_color                 (const GdkRGBA      *color,
+GdkPaintable*        gcal_get_paintable_from_color               (const GdkRGBA      *color,
                                                                   gint                size);
 
-cairo_surface_t*     get_circle_surface_from_color               (const GdkRGBA      *color,
+GdkPaintable*        get_circle_paintable_from_color             (const GdkRGBA      *color,
                                                                   gint                size);
 
+GdkPixbuf*           paintable_to_pixbuf                         (GdkPaintable       *paintable);
+
 void                 get_color_name_from_source                  (ESource            *source,
                                                                   GdkRGBA            *out_color);
 
@@ -104,31 +110,31 @@ gint                 get_alarm_trigger_minutes                   (GcalEvent
                                                                   ECalComponentAlarm *alarm);
 
 gboolean             should_change_date_for_scroll               (gdouble            *scroll_value,
-                                                                  GdkEventScroll     *scroll_event);
+                                                                  GdkEvent           *scroll_event);
 
 gboolean             is_source_enabled                           (ESource            *source);
 
-gboolean             ask_recurrence_modification_type            (GtkWidget             *parent,
-                                                                  GcalRecurrenceModType *modtype,
-                                                                  GcalCalendar          *calendar);
-
 gboolean             is_workday                                  (guint	              day);
 
-GList*               filter_event_list_by_uid_and_modtype        (GList                 *widgets,
+GList*               filter_children_by_uid_and_modtype          (GtkWidget             *widget,
                                                                   GcalRecurrenceModType  mod,
                                                                   const gchar           *uid);
 
-gboolean             gcal_translate_child_window_position        (GtkWidget           *target,
-                                                                  GdkWindow           *child_window,
-                                                                  gdouble              src_x,
-                                                                  gdouble              src_y,
-                                                                  gdouble             *real_x,
-                                                                  gdouble             *real_y);
-
 void                 gcal_utils_launch_online_accounts_panel     (GDBusConnection     *connection,
                                                                   const gchar         *action,
                                                                   const gchar         *arg);
 
 gchar*               gcal_utils_format_filename_for_display      (const gchar         *filename);
 
+void                 gcal_utils_extract_google_section           (const gchar        *description,
+                                                                  gchar             **out_description,
+                                                                  gchar             **out_meeting_url);
+
+void                 gcal_utils_ask_recurrence_modification_type (GtkWidget                 *parent,
+                                                                  GcalEvent                 *event,
+                                                                  GcalAskRecurrenceCallback  callback,
+                                                                  gpointer                   user_data);
+
+const gchar *        gcal_util_translate_time_string             (const gchar          *str);
+
 #endif /* __GCAL_UTILS_H__ */
